@@ -3,7 +3,7 @@ import datetime
 from decorator import decorator
 
 
-class DateTimeException(Exception):
+class CrashAtException(Exception):
     message = "This method has stopped worked"
 
 
@@ -13,8 +13,8 @@ def crash_after(func, date: str = None, *args, **kwargs):
         return func(*args, **kwargs)
 
     now = datetime.datetime.now()
-    _crash_after = datetime.datetime.strptime(date, "%m/%d/%y")
+    _crash_after = datetime.datetime.strptime(date, "%m/%d/%Y")
     if _crash_after < now:
-        raise DateTimeException
+        raise CrashAtException("This method expired in it's corrent form on {0}".format(date))
 
     return func(*args, **kwargs)
